********************************
Streams (generic high-level API)
********************************

.. currentmodule:: gruvi

Streams provide a generic, high-level API to work with connection-oriented
transports using file-like, blocking and flow-controlled API.

Utility classes
===============

.. autoclass:: gruvi.StreamReader
    :members:
    :show-inheritance:

.. autoclass:: gruvi.StreamWriter
    :members:
    :show-inheritance:

.. autoclass:: gruvi.ReadWriteStream
    :members:
    :show-inheritance:

Stream Protocol
===============

.. autoclass:: gruvi.StreamProtocol
    :members:
    :show-inheritance:

Stream Client and Server
========================

.. autoclass:: gruvi.StreamClient
    :members:
    :show-inheritance:

.. autoclass:: gruvi.StreamServer
    :members:
    :show-inheritance:
